# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'Estado'
        db.create_table(u'WebAplication_estado', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('nombre', self.gf('django.db.models.fields.CharField')(max_length=100)),
        ))
        db.send_create_signal(u'WebAplication', ['Estado'])

        # Adding unique constraint on 'Estado', fields ['nombre']
        db.create_unique(u'WebAplication_estado', ['nombre'])

        # Adding model 'Municipio'
        db.create_table(u'WebAplication_municipio', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('estado', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['WebAplication.Estado'])),
            ('nombre', self.gf('django.db.models.fields.CharField')(max_length=100)),
            ('clave', self.gf('django.db.models.fields.CharField')(max_length=4)),
        ))
        db.send_create_signal(u'WebAplication', ['Municipio'])

        # Adding unique constraint on 'Municipio', fields ['nombre', 'estado']
        db.create_unique(u'WebAplication_municipio', ['nombre', 'estado_id'])

        # Adding model 'Localidad'
        db.create_table(u'WebAplication_localidad', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('municipio', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['WebAplication.Municipio'])),
            ('nombre', self.gf('django.db.models.fields.CharField')(max_length=100)),
            ('listo', self.gf('django.db.models.fields.CharField')(max_length=60)),
        ))
        db.send_create_signal(u'WebAplication', ['Localidad'])

        # Adding model 'Domicilio'
        db.create_table(u'WebAplication_domicilio', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('calle', self.gf('django.db.models.fields.CharField')(max_length=100, null=True, blank=True)),
            ('numero', self.gf('django.db.models.fields.CharField')(max_length=10, null=True, blank=True)),
            ('codigo_postal', self.gf('django.db.models.fields.IntegerField')(max_length=5, null=True, blank=True)),
            ('colonia', self.gf('django.db.models.fields.CharField')(max_length=500)),
            ('longitud', self.gf('django.db.models.fields.IntegerField')(max_length=10, null=True, blank=True)),
            ('latitud', self.gf('django.db.models.fields.IntegerField')(max_length=10, null=True, blank=True)),
            ('localidad', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['WebAplication.Localidad'])),
        ))
        db.send_create_signal(u'WebAplication', ['Domicilio'])

        # Adding model 'Sexo'
        db.create_table(u'WebAplication_sexo', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('tipo', self.gf('django.db.models.fields.CharField')(max_length='10')),
        ))
        db.send_create_signal(u'WebAplication', ['Sexo'])

        # Adding model 'Persona'
        db.create_table(u'WebAplication_persona', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('fecha_registro', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
            ('nombre', self.gf('django.db.models.fields.CharField')(max_length=50)),
            ('apellido_paterno', self.gf('django.db.models.fields.CharField')(max_length=30)),
            ('apellido_materno', self.gf('django.db.models.fields.CharField')(max_length=30)),
            ('sexo', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['WebAplication.Sexo'])),
            ('fecha_nacimiento', self.gf('django.db.models.fields.DateField')()),
            ('domicilio', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['WebAplication.Domicilio'])),
            ('curp', self.gf('django.db.models.fields.CharField')(max_length=20)),
            ('activo', self.gf('django.db.models.fields.BooleanField')(default=True)),
        ))
        db.send_create_signal(u'WebAplication', ['Persona'])

        # Adding unique constraint on 'Persona', fields ['domicilio', 'sexo', 'curp']
        db.create_unique(u'WebAplication_persona', ['domicilio_id', 'sexo_id', 'curp'])

        # Adding M2M table for field tipo on 'Persona'
        m2m_table_name = db.shorten_name(u'WebAplication_persona_tipo')
        db.create_table(m2m_table_name, (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('persona', models.ForeignKey(orm[u'WebAplication.persona'], null=False)),
            ('tipopersona', models.ForeignKey(orm[u'WebAplication.tipopersona'], null=False))
        ))
        db.create_unique(m2m_table_name, ['persona_id', 'tipopersona_id'])

        # Adding model 'Credencial'
        db.create_table(u'WebAplication_credencial', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('folio', self.gf('django.db.models.fields.CharField')(max_length=13, null=True, blank=True)),
            ('anio_registro', self.gf('django.db.models.fields.IntegerField')()),
            ('clave_elector', self.gf('django.db.models.fields.CharField')(max_length=30)),
            ('ocr', self.gf('django.db.models.fields.CharField')(max_length=20, null=True, blank=True)),
            ('persona', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['WebAplication.Persona'], null=True, blank=True)),
        ))
        db.send_create_signal(u'WebAplication', ['Credencial'])

        # Adding unique constraint on 'Credencial', fields ['folio', 'clave_elector', 'ocr', 'persona']
        db.create_unique(u'WebAplication_credencial', ['folio', 'clave_elector', 'ocr', 'persona_id'])

        # Adding model 'TipoPersona'
        db.create_table(u'WebAplication_tipopersona', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('descripcion', self.gf('django.db.models.fields.CharField')(max_length=30)),
            ('fecha', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
        ))
        db.send_create_signal(u'WebAplication', ['TipoPersona'])


    def backwards(self, orm):
        # Removing unique constraint on 'Credencial', fields ['folio', 'clave_elector', 'ocr', 'persona']
        db.delete_unique(u'WebAplication_credencial', ['folio', 'clave_elector', 'ocr', 'persona_id'])

        # Removing unique constraint on 'Persona', fields ['domicilio', 'sexo', 'curp']
        db.delete_unique(u'WebAplication_persona', ['domicilio_id', 'sexo_id', 'curp'])

        # Removing unique constraint on 'Municipio', fields ['nombre', 'estado']
        db.delete_unique(u'WebAplication_municipio', ['nombre', 'estado_id'])

        # Removing unique constraint on 'Estado', fields ['nombre']
        db.delete_unique(u'WebAplication_estado', ['nombre'])

        # Deleting model 'Estado'
        db.delete_table(u'WebAplication_estado')

        # Deleting model 'Municipio'
        db.delete_table(u'WebAplication_municipio')

        # Deleting model 'Localidad'
        db.delete_table(u'WebAplication_localidad')

        # Deleting model 'Domicilio'
        db.delete_table(u'WebAplication_domicilio')

        # Deleting model 'Sexo'
        db.delete_table(u'WebAplication_sexo')

        # Deleting model 'Persona'
        db.delete_table(u'WebAplication_persona')

        # Removing M2M table for field tipo on 'Persona'
        db.delete_table(db.shorten_name(u'WebAplication_persona_tipo'))

        # Deleting model 'Credencial'
        db.delete_table(u'WebAplication_credencial')

        # Deleting model 'TipoPersona'
        db.delete_table(u'WebAplication_tipopersona')


    models = {
        u'WebAplication.credencial': {
            'Meta': {'unique_together': "(['folio', 'clave_elector', 'ocr', 'persona'],)", 'object_name': 'Credencial'},
            'anio_registro': ('django.db.models.fields.IntegerField', [], {}),
            'clave_elector': ('django.db.models.fields.CharField', [], {'max_length': '30'}),
            'folio': ('django.db.models.fields.CharField', [], {'max_length': '13', 'null': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'ocr': ('django.db.models.fields.CharField', [], {'max_length': '20', 'null': 'True', 'blank': 'True'}),
            'persona': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['WebAplication.Persona']", 'null': 'True', 'blank': 'True'})
        },
        u'WebAplication.domicilio': {
            'Meta': {'object_name': 'Domicilio'},
            'calle': ('django.db.models.fields.CharField', [], {'max_length': '100', 'null': 'True', 'blank': 'True'}),
            'codigo_postal': ('django.db.models.fields.IntegerField', [], {'max_length': '5', 'null': 'True', 'blank': 'True'}),
            'colonia': ('django.db.models.fields.CharField', [], {'max_length': '500'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'latitud': ('django.db.models.fields.IntegerField', [], {'max_length': '10', 'null': 'True', 'blank': 'True'}),
            'localidad': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['WebAplication.Localidad']"}),
            'longitud': ('django.db.models.fields.IntegerField', [], {'max_length': '10', 'null': 'True', 'blank': 'True'}),
            'numero': ('django.db.models.fields.CharField', [], {'max_length': '10', 'null': 'True', 'blank': 'True'})
        },
        u'WebAplication.estado': {
            'Meta': {'ordering': "['nombre']", 'unique_together': "(['nombre'],)", 'object_name': 'Estado'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'nombre': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        u'WebAplication.localidad': {
            'Meta': {'ordering': "['nombre']", 'object_name': 'Localidad'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'listo': ('django.db.models.fields.CharField', [], {'max_length': '60'}),
            'municipio': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['WebAplication.Municipio']"}),
            'nombre': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        u'WebAplication.municipio': {
            'Meta': {'ordering': "['nombre']", 'unique_together': "(['nombre', 'estado'],)", 'object_name': 'Municipio'},
            'clave': ('django.db.models.fields.CharField', [], {'max_length': '4'}),
            'estado': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['WebAplication.Estado']"}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'nombre': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        u'WebAplication.persona': {
            'Meta': {'unique_together': "(['domicilio', 'sexo', 'curp'],)", 'object_name': 'Persona'},
            'activo': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'apellido_materno': ('django.db.models.fields.CharField', [], {'max_length': '30'}),
            'apellido_paterno': ('django.db.models.fields.CharField', [], {'max_length': '30'}),
            'curp': ('django.db.models.fields.CharField', [], {'max_length': '20'}),
            'domicilio': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['WebAplication.Domicilio']"}),
            'fecha_nacimiento': ('django.db.models.fields.DateField', [], {}),
            'fecha_registro': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'nombre': ('django.db.models.fields.CharField', [], {'max_length': '50'}),
            'sexo': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['WebAplication.Sexo']"}),
            'tipo': ('django.db.models.fields.related.ManyToManyField', [], {'to': u"orm['WebAplication.TipoPersona']", 'symmetrical': 'False'})
        },
        u'WebAplication.sexo': {
            'Meta': {'object_name': 'Sexo'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'tipo': ('django.db.models.fields.CharField', [], {'max_length': "'10'"})
        },
        u'WebAplication.tipopersona': {
            'Meta': {'object_name': 'TipoPersona'},
            'descripcion': ('django.db.models.fields.CharField', [], {'max_length': '30'}),
            'fecha': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'})
        }
    }

    complete_apps = ['WebAplication']