#encoding:utf-8
from django.db import models
from datetime import datetime


#modelo para realizar un cuestionario a alumnos del servicio social, para indicar  el area donde tienen mas fortaleza

class Alumno(models.Model):
	""" 
	Clase alumno  genera un objeto que contiene los siguentes datos:
	nombre del alumno, apellido paterno y materno, institucion de donde proviene, 
	carrera, semeste, y la fecha hace referencia a la fecha cuando realizo el cuestionario

	"""
	nombre_alumno=models.CharField("Nombre",max_length=50)
	appat=models.CharField("Apellido Paterno",max_length=50)
	apma=models.CharField("Apellido Materno",max_length=50)
	institucion=models.CharField("Institución",max_length=100)
	carrera=models.CharField(" Carrera",max_length=100)
	semestre=models.CharField("Semestre",max_length=50)
	fecha=models.DateTimeField("Fecha de Registro",auto_now=True)
	
	def __unicode__(self): 
		return self.nombre_alumno
	
		
class Area(models.Model):
	""" 
	Clase Area se define con el area al cual pertenece el cuestionario
	que se aplicara , en este caso son 3 : Soporte, Infraestructura y Desarrollo
	"""
	nombre_area=models.CharField("Nombre",max_length=50)
	color_area=models.CharField("Color",max_length=50)
	def __unicode__(self):
		return self.nombre_area

class Pregunta(models.Model):
	""" 
	La clase  define la pregunta que se almacenara, esta 
	se asocia  a una area en particular

	"""
	area=models.ForeignKey(Area, verbose_name="Area de la Pregunta")
	nombre_pregunta=models.CharField("Pregunta", max_length=200)
	def __unicode__(self):
		return self.nombre_pregunta

class Respuesta(models.Model):
	""" 
	Clase respuesta define la respuestas que se asocian a una pregunta 
	en particular y contiene un dato booleano para definir cual respuesta
	es la correcta 

	"""
	pregunta= models.ForeignKey(Pregunta, verbose_name="Pregunta")
	nom_respuesta=models.CharField("Respuesta", max_length=200)
	acierto=models.BooleanField("Respuesta Correcta")
	
	def __unicode__(self):
		return self.nom_respuesta

class Resultado(models.Model):
	""" 
	Clase Resultado  define los  respuestas de cada alumno, asignando el valor 1 para los aciertos y asignando 0 en caso contrario.


	"""
	alumno=models.ForeignKey(Alumno, verbose_name="Nombre del alumno")
	respuesta=models.ForeignKey(Respuesta, verbose_name="Respuesta")
	cont_respuesta=models.IntegerField("Contador",default=0)

	
	def __unicode__(self):
		
		return u'%s' % self.cont_respuesta







